#!/bin/bash
#

# this script builds both ifdhc and ifdhc_config
# need an in source build

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <e9:p2711|e10:p2711|e10:p2713b|e10:p2713d|e14:p2713b|e14:p2713d> <debug|opt|prof> [tar]"
   echo "        p2713b -> python v2_7_13b"
   echo "        p2711 -> python v2_7_11"
   echo "        e14 -> gcc v6_3_0"
   echo "        e10 -> gcc v4_9_3a"
   echo "        e9 -> gcc v4_9_3"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}

    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims"
       exit 1
    fi

}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
extraqual=${3}
maketar=${4}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=ifdhc
origpkgver=v2_0_6a
pkgver=${origpkgver}
ssibuildshims_version=v0_16_00
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarver=`echo ${origpkgver} | sed -e 's/_/./g'`
pkgtarfile=${package}-${origpkgver}.tar 

get_this_dir

get_ssibuildshims

source define_basics
#configdir=${product_dir}/ifdhc_config/${pkgver}
pkgups=${product_dir}/${package}/${pkgver}/ups

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   cd ${product_dir}
   tar cjf ifdhc_config-${pkgdotver}-noarch.tar.bz2 ifdhc_config/${pkgver} ifdhc_config/${pkgver}.version ifdhc_config/current.chain
   exit 0
fi

echo "building ${package} for ${OS}-${plat}-${qualdir} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi
mkdir -p ${pkgups}
if [ ! -d ${pkgups} ]
then
   echo "ERROR: failed to create ${pkgups}"
   exit 1
fi

cd ${pkgdir} 
tar xf ${tardir}/${pkgtarfile} || ssi_die "ERROR: failed to unwind ${pkgtarfile}"
patch -b -p0 < "${patchdir}/ifdhc.patch" || ssi_die "ERROR: application of patch ${patchdir}/ifdhc.patch failed."
cp -p ${pkgdir}/ups/ifdhc.table ${pkgups}/ || ssi_die "ERROR: copy of ups table file failed"

echo
if  ups exist ifdhc_config ${pkgver} -z ${product_dir} >/dev/null 2>&1; then
   echo "ifdhc_config ${pkgver} is already installed"
else
   echo "install ifdhc_config ${pkgver}"
   ${pkgdir}/ups/install_ifdhc_config.sh ${product_dir} ${pkgver} || ssi_die "ERROR: install of ifdhc_config failed"
fi
#ups list -aK+ ifdhc_config ${pkgver} -z ${product_dir}

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

setup -B ${package} ${pkgver} -q ${fullqual} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "ERROR: fake setup failed"
echo
echo "PYTHONHOME is ${PYTHONHOME}"

ncore=`${SSIBUILDSHIMS_DIR}/bin/ncores`

case ${basequal} in
e9:p2710) stdcxx="-std=c++1y" ;;
e9:p2711) stdcxx="-std=c++1y" ;;
e10:p2710) stdcxx="-std=c++14" ;;
e10:p2711) stdcxx="-std=c++14" ;;
e10:p2713b) stdcxx="-std=c++14" ;;
e10:p2713d) stdcxx="-std=c++14" ;;
e14:p2713b) stdcxx="-std=c++14" ;;
e14:p2713d) stdcxx="-std=c++14" ;;
*) 
   echo "ERROR: unrecognized qualifier ${basequal}"
   usage
   exit 1
esac

case ${extraqual} in
debug) ARCH="${stdcxx} -O0 -g";;
prof)  ARCH="${stdcxx} -g -p -pg";;
opt)   ARCH="${stdcxx} -O2";;
esac
export ARCH

export PYTHON_CONF=`echo $PYTHON_LIB/python*/config`

# check for swig
type swig >& /dev/null
swigstat=$?
if [[ ${swigstat} ]]
then

swig_minor=`swig -version | grep Version | cut -f 3 -d " " | cut -f 2 -d "."`
swig_patch=`swig -version | grep Version | cut -f 3 -d " " | cut -f 3 -d "."`

if [ ${swig_minor} -eq 3 ] && [ ${swig_patch} -ge 40 ]
then
 mv ${pkgdir}/ifdh/ifdh_wrap.patch ${pkgdir}/ifdh/ifdh_wrap.patch.orig
 cp -p ${patchdir}/ifdh_wrap.patch ${pkgdir}/ifdh/ifdh_wrap.patch
elif [ ${swig_minor} -gt 3 ]
then
 mv ${pkgdir}/ifdh/ifdh_wrap.patch ${pkgdir}/ifdh/ifdh_wrap.patch.orig
 cp -p ${patchdir}/ifdh_wrap.patch ${pkgdir}/ifdh/ifdh_wrap.patch
fi

else

  echo "swig is not available"

fi
echo

set -x

cd ${pkgdir} 

make IFDHC_VERSION=${origpkgver} all || ssi_die "ERROR: make all failed"
make install || ssi_die "ERROR: make install failed"
make clean || ssi_die "ERROR: make clean failed"

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi


# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
echo "unsetup"
unsetup ${package}
echo "setup"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}:${PRODUCTS} || ssi_die "ERROR: setup failed"

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   cd ${product_dir}
   tar cjf ifdhc_config-${pkgdotver}-noarch.tar.bz2 ifdhc_config/${pkgver} ifdhc_config/${pkgver}.version  ifdhc_config/current.chain

fi

exit 0
